==> haskell-criterion-1.6.3.0-39-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-criterion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 criterion
version:              1.6.3.0
visibility:           public
id:                   criterion-1.6.3.0-EVdyIdeoyBq1AEtl7Ul0aP
key:                  criterion-1.6.3.0-EVdyIdeoyBq1AEtl7Ul0aP
license:              BSD-3-Clause
copyright:            2009-2016 Bryan O'\''Sullivan and others
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://www.serpentine.com/criterion
synopsis:             Robust, reliable performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.

    The fastest way to get started is to read the
    <http://www.serpentine.com/criterion/tutorial.html online tutorial>,
    followed by the documentation and examples in the "Criterion.Main"
    module.

    For examples of the kinds of reports that criterion generates, see
    <http://www.serpentine.com/criterion the home page>.

category:             Development, Performance, Testing, Benchmarking
abi:                  4ae506feeb2a2d546a5f27f9f7af08f9
exposed:              True
exposed-modules:
    Criterion Criterion.Analysis Criterion.IO Criterion.IO.Printf
    Criterion.Internal Criterion.Main Criterion.Main.Options
    Criterion.Monad Criterion.Report Criterion.Types

hidden-modules:       Criterion.Monad.Internal Paths_criterion
import-dirs:          /usr/lib/ghc-9.6.6/site-local/criterion-1.6.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/criterion-1.6.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/criterion-1.6.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-criterion
hs-libraries:         HScriterion-1.6.3.0-EVdyIdeoyBq1AEtl7Ul0aP
depends:
    Glob-0.10.2-AkNemguOk3X5pWzckA4YZJ
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1
    base-compat-batteries-0.14.1-lgVr2peCDw5qXG4VLbklv binary-0.8.9.1
    binary-orphans-1.0.5-1VCGcurzJlr6bEl6Wn9GAU bytestring-0.11.5.3
    cassava-0.5.4.1-I5H7lXHpRMwDMqqRDQwXhI
    code-page-0.2.1-8r7bPp8D9hK7XmJl89SAkA containers-0.6.7
    criterion-measurement-0.2.3.0-GTVpwTo2u8PcyeGoHvPw3 deepseq-1.4.8.1
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    js-chart-2.9.4.1-Es3f7aYy6XKGmoiCGVJgsO
    microstache-1.0.2.3-8fnrAQb2wwZcWgs9AtzqU mtl-2.3.1
    mwc-random-0.15.2.0-C3D8kiUTx4cAR7alE49l8B
    optparse-applicative-0.18.1.0-AbA9pm273O8LTotNJ1t1CE
    parsec-3.1.16.1 prettyprinter-1.7.1-KtmqmFkRxIvL2FcrwTTeTo
    prettyprinter-ansi-terminal-1.1.3-LcajTeMLJmqJgHikO6kzwA
    statistics-0.16.4.0-9Q6H9mAUCah5tltD2NR4Ny text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP
    vector-algorithms-0.9.1.0-nPezpE6T5gHv4BTs4clf9

haddock-interfaces:   /usr/share/doc/haskell-criterion/html/criterion.haddock
haddock-html:         /usr/share/doc/haskell-criterion/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-criterion-1.6.3.0-40-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-criterion.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 criterion
version:              1.6.3.0
visibility:           public
id:                   criterion-1.6.3.0-5tw2toVzF2wACV0juPU8qZ
key:                  criterion-1.6.3.0-5tw2toVzF2wACV0juPU8qZ
license:              BSD-3-Clause
copyright:            2009-2016 Bryan O'\''Sullivan and others
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://www.serpentine.com/criterion
synopsis:             Robust, reliable performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.

    The fastest way to get started is to read the
    <http://www.serpentine.com/criterion/tutorial.html online tutorial>,
    followed by the documentation and examples in the "Criterion.Main"
    module.

    For examples of the kinds of reports that criterion generates, see
    <http://www.serpentine.com/criterion the home page>.

category:             Development, Performance, Testing, Benchmarking
abi:                  222106d34f9b74b7e609e0673be0d730
exposed:              True
exposed-modules:
    Criterion Criterion.Analysis Criterion.IO Criterion.IO.Printf
    Criterion.Internal Criterion.Main Criterion.Main.Options
    Criterion.Monad Criterion.Report Criterion.Types

hidden-modules:       Criterion.Monad.Internal Paths_criterion
import-dirs:          /usr/lib/ghc-9.6.6/site-local/criterion-1.6.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/criterion-1.6.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/criterion-1.6.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-criterion
hs-libraries:         HScriterion-1.6.3.0-5tw2toVzF2wACV0juPU8qZ
depends:
    Glob-0.10.2-5kv8V0ytwO85Bs2S1wsFnS
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1
    base-compat-batteries-0.14.1-7XhCMBTAbUaB4cukby3R0h binary-0.8.9.1
    binary-orphans-1.0.5-2QdNlgpLYWR3AHIOi4WILQ bytestring-0.11.5.3
    cassava-0.5.4.1-1CM8h0noLla7Uv16d8t4LK
    code-page-0.2.1-8r7bPp8D9hK7XmJl89SAkA containers-0.6.7
    criterion-measurement-0.2.3.0-gtGIRYSHl9ETYuz9xAQfL deepseq-1.4.8.1
    directory-1.3.8.5 exceptions-0.10.7 filepath-1.4.300.1
    js-chart-2.9.4.1-Es3f7aYy6XKGmoiCGVJgsO
    microstache-1.0.2.3-KKsw6fNygFtG16m7n2m4CK mtl-2.3.1
    mwc-random-0.15.2.0-DaAM0ROjU9kKbsqzvOqtbb
    optparse-applicative-0.18.1.0-BnGHnrTdK6d4c7MmJxSY0G
    parsec-3.1.16.1 prettyprinter-1.7.1-BsaWeUw0po1KNye7GKTBJ
    prettyprinter-ansi-terminal-1.1.3-8bIrDelGjXzHJngnsc4lAf
    statistics-0.16.4.0-6V2CAmS2jrIKJpG35SBo4F text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH
    vector-algorithms-0.9.1.0-GdPL2rq4cry7HNPKxZ4cz0

haddock-interfaces:   /usr/share/doc/haskell-criterion/html/criterion.haddock
haddock-html:         /usr/share/doc/haskell-criterion/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
